Struct google_customsearch1::api::CseMethods [−][src]
A builder providing access to all methods supported on cse resources.
It is not used directly, but through the CustomSearchAPI hub.
Example
Instantiate a resource builder
extern crate hyper; extern crate hyper_rustls; extern crate yup_oauth2 as oauth2; extern crate google_customsearch1 as customsearch1; use std::default::Default; use oauth2; use customsearch1::CustomSearchAPI; let secret: oauth2::ApplicationSecret = Default::default(); let auth = yup_oauth2::InstalledFlowAuthenticator::builder( secret, yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect, ).build().await.unwrap(); let mut hub = CustomSearchAPI::new(hyper::Client::builder().build(hyper_rustls::HttpsConnector::with_native_roots()), auth); // Usually you wouldn't bind this to a variable, but keep calling *CallBuilders* // like `list(...)` and `siterestrict_list(...)` // to build up your call. let rb = hub.cse();
Implementations
impl<'a> CseMethods<'a>[src]
pub fn siterestrict_list(&self) -> CseSiterestrictListCall<'a>[src]
Create a builder to help you perform the following task:
Returns metadata about the search performed, metadata about the engine used for the search, and the search results. Uses a small set of url patterns.
pub fn list(&self) -> CseListCall<'a>[src]
Create a builder to help you perform the following task:
Returns metadata about the search performed, metadata about the engine used for the search, and the search results.